@@ -1,5 +1,3 @@
-=encoding utf8
-
 =head1 NAME
 
 Locale::SubCountry - Convert state, province, county etc. names to/from ISO 3166-2 codes
@@ -7,7 +5,7 @@ Locale::SubCountry - Convert state, province, county etc. names to/from ISO 3166
 =head1 SYNOPSIS
 
     my $country_code = 'GB';
-    my $UK = new Locale::SubCountry($country_code);
+    my $UK = Locale::SubCountry->new($country_code);
     if ( not $UK )
     {
         die "Invalid code $country_code\n";
@@ -18,7 +16,7 @@ Locale::SubCountry - Convert state, province, county etc. names to/from ISO 3166
         print($UK->regional_division('DGY'),"\n");   # SCT (Scotland)
     }
 
-    my $australia = new Locale::SubCountry('Australia');
+    my $australia = Locale::SubCountry->new('Australia');
     if ( not $australia )
     {
         die "Invalid code: Australia\n";
@@ -52,7 +50,7 @@ Locale::SubCountry - Convert state, province, county etc. names to/from ISO 3166
 
     # Methods for country codes and names
 
-    my $world = new Locale::SubCountry::World;
+    my $world = Locale::SubCountry::World->new();
     my @all_countries     = $world->all_full_names;
     my @all_country_codes = $world->all_codes;
 
@@ -68,7 +66,7 @@ can also be done. Sub country codes are defined in "ISO 3166-2:2007,
 Codes for the representation of names of countries and their subdivisions".
 
 Sub countries are termed as states in the US and Australia, provinces
-in Canada and counties in the UK and Ireland. Ohter terms include region,
+in Canada and counties in the UK and Ireland. Other terms include region,
 department, city and territory.
 
 Names and ISO 3166-2 codes for all sub countries in a country can be
@@ -98,7 +96,7 @@ sure that your chosen method is acting on the correct type of object.
     full_name_code_hash
 
 
-=head2 new Locale::SubCountry::World
+=head2  Locale::SubCountry::World->new()
 
 The C<new> method creates an instance of a world country object. This must be
 called before any of the following methods are invoked. The method takes no
@@ -127,7 +125,7 @@ Given a world object, returns an array of all country IS) 3166-1 codes,
 sorted alphabetically.
 
 
-=head2 new Locale::SubCountry
+=head2 Locale::SubCountry->new()
 
 The C<new> method creates an instance of a sub country object. This must be
 called before any of the following methods are invoked. The method takes a
@@ -187,7 +185,7 @@ or "unknown" if no match is found.
 
 Given a sub country object, the C<regional_division> method takes the
 ISO 3166-2 code of a sub country and returns the sub country's
-regionional_division. This is, an alphanumeric code. The regional_division
+regional_division. This is an alphanumeric code. The regional_division
 is returned as a capitalised string,  or "unknown" if no match is found.
 
 =head2 has_sub_countries
@@ -277,8 +275,8 @@ the correct code for that sub country. These entries are usually duplicated
 because the name represents two different types of sub country, such as a
 province and a geographical unit. Examples are:
 
-    AZERBAIJAN : Lnkran; LA (the City), LAN (the Rayon)
-    AZERBAIJAN : Ski; SA,SAK
+    AZERBAIJAN : Lankaran; LA (the City), LAN (the Rayon) [see note]
+    AZERBAIJAN : Saki; SA,SAK [see note]
     AZERBAIJAN : Susa; SS,SUS
     AZERBAIJAN : Yevlax; YE,YEV
     INDONESIA  : Kalimantan Timur; KI,KT
@@ -290,6 +288,11 @@ province and a geographical unit. Examples are:
     MOLDOVA    : Gngheni; UN,UGI
     MOZAMBIQUE : Maputo; MPM,L
 
+Note: these names are spelt with a diaeresis character (two dots) above
+some of the 'a' characters. This causes utf8 errors on some versions
+of Perl, so they are omitted here. See the Locale::SubCountry::Data module
+for correct spelling
+
 FIPS codes are not provided for all sub countries.
 
 
@@ -309,18 +312,16 @@ this module.
 
 Mark Summerfield and Guy Fraser provided the list of UK counties.
 
-TJ Mather supplied the FIPS codes and many ammendments to the sub country data
+TJ Mather supplied the FIPS codes and many amendments to the sub country data
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2013 Kim Ryan. All rights reserved.
+Copyright (c) 2015 Kim Ryan. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-
-
 =cut
 
 #-------------------------------------------------------------------------------
@@ -334,7 +335,7 @@ use Locale::SubCountry::Data;
 #-------------------------------------------------------------------------------
 
 package Locale::SubCountry::World;
-our $VERSION = '1.61';
+our $VERSION = '1.65';
 
 # Define all the methods for the 'world' class here. Note that because the
 # name space inherits from the Locale::SubCountry name space, the
@@ -390,7 +391,7 @@ sub all_codes
 #-------------------------------------------------------------------------------
 
 package Locale::SubCountry;
-our $VERSION = '1.61';
+our $VERSION = '1.65';
 
 #-------------------------------------------------------------------------------
 # Initialization code must be run first to create global data structure.
@@ -595,6 +596,12 @@ sub code
     my $sub_country = shift;
     my ($full_name) = @_;
 
+    unless ( $sub_country->has_sub_countries )
+    {
+        # this country has no sub countries
+        return;
+    }
+
     my $orig = $full_name;
 
     $full_name = _clean($full_name);
@@ -730,6 +737,12 @@ sub full_name
     my $sub_country = shift;
     my ($code,$uc_name) = @_;
 
+    unless ( $sub_country->has_sub_countries )
+    {
+        # this country has no sub countries
+        return;
+    }
+
     $code = _clean($code);
     $code = uc($code);
 
